@@ -2,7 +2,7 @@
 #
 # QBzr - Qt frontend to Bazaar commands
 # Copyright (C) 2008 Lukáš Lalinský <lalinsky@gmail.com>
-# Copyright (C) 2009, 2010 QBzr Developers
+# Copyright (C) 2009, 2010, 2011, 2012 QBzr Developers
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@ Basic q-commands:
  * qconflicts - Show conflicts.
  * qdiff - Show differences in working tree in a GUI window.
  * qexport - Export current or past revision to a destination directory or archive.
+ * qignore - Ignore files or patterns.
  * qinfo - Shows information about the current location.
  * qinit - Initializes a new branch or shared repository.
  * qlog - Show log of a repository, branch, file, or directory in a Qt window.
@@ -51,7 +52,7 @@ Basic q-commands:
  * qunbind - Convert the current checkout into a regular branch.
  * quncommit - Move the tip of a branch to an earlier revision.
  * qupdate - Update working tree with latest changes in the branch.
- * qverify-signatures - Show digital signatures information.
+ * qverify-signatures - Show digital signatures information
  * qversion - Show version/system information.
 
 Hybrid dialogs:
@@ -71,7 +72,7 @@ Miscellaneous:
  * bug-url - print full URL to a specific bug, or open it in your browser.
 """
 
-version_info = (0, 21, 2, 'final', 0)
+version_info = (0, 22, 2, 'final', 0)
 __version__ = '.'.join(map(str, version_info))
 
 
@@ -123,6 +124,7 @@ lazy_commands = (
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qgetnew', ['qgetn']),
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qgetupdates', ['qgetu', 'qgetup']),
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qhelp', []),
+    ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qignore', []),
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qinfo', []),
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qinit', []),
     ('bzrlib.plugins.qbzr.lib.commands', 'cmd_qlog', []),
