@@ -60,10 +60,12 @@ class AddWindow(SubProcessDialog):
         self.filelist = TreeWidget(groupbox)
         self.filelist.throbber = self.throbber
         self.filelist.tree_model.is_item_in_select_all = lambda item: (
+            # Is in select all. - Not versioned, and not Ignored
             item.change is not None and
             item.change.is_ignored() is None and
             not item.change.is_versioned(), 
             
+            # look at children. - Not ignored
             item.change is not None and item.change.is_ignored() is None or
             item.change is None
             )
@@ -154,6 +156,6 @@ class AddWindow(SubProcessDialog):
         fmodel.setFilter(fmodel.IGNORED, state)
         #self.filelist.update_selectall_state(None, None)
 
-    def saveSize(self):
-        SubProcessDialog.saveSize(self)
-        self.saveSplitterSizes()
+    def _saveSize(self, config):
+        SubProcessDialog._saveSize(self, config)
+        self._saveSplitterSizes(config, self.splitter)
