@@ -199,7 +199,7 @@ execute_option = Option("execute", short_name='e',
          "waiting for user input.")
 
 # A special option so 'revision' can be passed as a simple string, when we do
-# *not* wan't bzrlib's feature of parsing the revision string before passing it.
+# *not* want bzrlib's feature of parsing the revision string before passing it.
 # This is used when we just want a plain string to pass to our dialog for it to
 # display in the UI, and we will later pass it to bzr for parsing. If you want
 # bzrlib to parse and pass a revisionspec object, just pass the string
@@ -265,7 +265,8 @@ class cmd_qannotate(QBzrCommand):
             file_id = tree.path2id(relpath)
             if file_id is None:
                 raise errors.NotVersionedError(filename)
-            entry = tree.inventory[file_id]
+            [(path, entry)] = list(tree.iter_entries_by_dir(
+                specific_file_ids=[file_id]))
             if entry.kind != 'file':
                 raise errors.BzrCommandError(
                         'bzr qannotate only works for files (got %r)' % entry.kind)
@@ -300,7 +301,7 @@ class cmd_qadd(QBzrCommand):
     takes_options = [ui_mode_option]
 
     def _qbzr_run(self, selected_list=None, ui_mode=False):
-        tree, selected_list = builtins.tree_files(selected_list)
+        tree, selected_list = WorkingTree.open_containing_paths(selected_list)
         if selected_list == ['']:
             selected_list = None
         self.main_window = AddWindow(tree, selected_list, dialog=False, ui_mode=ui_mode)
@@ -314,7 +315,7 @@ class cmd_qrevert(QBzrCommand):
     takes_options = [ui_mode_option, bzr_option('revert', 'no-backup')]
 
     def _qbzr_run(self, selected_list=None, ui_mode=False, no_backup=False):
-        tree, selected_list = builtins.tree_files(selected_list)
+        tree, selected_list = WorkingTree.open_containing_paths(selected_list)
         if selected_list == ['']:
             selected_list = None
         self.main_window = RevertWindow(tree, selected_list, dialog=False,
@@ -376,7 +377,7 @@ class cmd_qcommit(QBzrCommand):
                 message = f.read().decode(file_encoding or osutils.get_user_encoding())
             finally:
                 f.close()
-        tree, selected_list = builtins.tree_files(selected_list)
+        tree, selected_list = WorkingTree.open_containing_paths(selected_list)
         if selected_list == ['']:
             selected_list = None
         self.main_window = CommitWindow(tree, selected_list, dialog=False,
@@ -852,7 +853,7 @@ class cmd_qgetnew(QBzrCommand):
     takes_options = [ui_mode_option]
     aliases = ['qgetn']
 
-    def _qbzr_run(self, location=CUR_DIR, ui_mode=False):
+    def _qbzr_run(self, location=None, ui_mode=False):
         from bzrlib.plugins.qbzr.lib.getnew import GetNewWorkingTreeWindow
         self.main_window = GetNewWorkingTreeWindow(location, ui_mode=ui_mode)
         self.main_window.show()
@@ -1146,3 +1147,19 @@ class cmd_qunshelve(QBzrCommand):
         self.main_window.show()
         self._application.exec_()
 
+
+class cmd_qignore(QBzrCommand):
+    """Ignore files or patterns."""
+    takes_args = []
+    takes_options = [
+        ui_mode_option,
+        bzr_option('ignore', 'directory'),
+        ]
+    aliases = []
+
+    def _qbzr_run(self, directory=None, ui_mode=False):
+        from bzrlib.plugins.qbzr.lib.ignore import IgnoreWindow
+        wt = WorkingTree.open_containing(directory)[0]
+        self.main_window = IgnoreWindow(tree=wt, ui_mode=ui_mode)
+        self.main_window.show()
+        self._application.exec_()
