@@ -27,6 +27,7 @@ from bzrlib.plugins.qbzr.lib.util import (
     BTN_REFRESH,
     file_extension,
     get_global_config,
+    get_qbzr_config,
     url_for_display,
     ThrobberWidget,
     runs_in_loading_queue,
@@ -89,9 +90,7 @@ class TextEdit(QtGui.QTextEdit):
             and e_key in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
             and (int(e.modifiers()) & QtCore.Qt.ControlModifier)):
                 e.ignore()
-                # FIXME probably this is ugly hack and main qcommit window
-                # should explicitly catch Ctrl+Enter by self
-                self.main_window.do_accept()
+                self.emit(QtCore.SIGNAL("messageEntered()"))
                 return
 
         isShortcut = e.modifiers() & QtCore.Qt.ControlModifier and e.key() == QtCore.Qt.Key_E
@@ -316,10 +315,18 @@ class CommitWindow(SubProcessDialog):
 
         self.show_nonversioned_checkbox = QtGui.QCheckBox(
             gettext("Show non-versioned files"))
+        show_nonversioned = get_qbzr_config().get_option_as_bool(self._window_name + "_show_nonversioned")
+        if show_nonversioned:
+            self.show_nonversioned_checkbox.setChecked(QtCore.Qt.Checked)
+        else:
+            self.show_nonversioned_checkbox.setChecked(QtCore.Qt.Unchecked)
 
         self.filelist = TreeWidget(self)
         self.filelist.throbber = self.throbber
-        self.filelist.tree_model.set_select_all_kind('versioned')
+        if show_nonversioned:
+            self.filelist.tree_model.set_select_all_kind('all')
+        else:
+            self.filelist.tree_model.set_select_all_kind('versioned')
         
         self.file_words = {}
         self.connect(self.filelist.tree_model,
@@ -335,6 +342,8 @@ class CommitWindow(SubProcessDialog):
         # Equivalent for 'bzr commit --message'
         self.message = TextEdit(spell_checker, message_groupbox, main_window=self)
         self.message.setToolTip(gettext("Enter the commit message"))
+        self.connect(self.message, QtCore.SIGNAL("messageEntered()"),
+                     self.do_accept)
         self.completer = QtGui.QCompleter()
         self.completer_model = QtGui.QStringListModel(self.completer)
         self.completer.setModel(self.completer_model)
@@ -458,6 +467,10 @@ class CommitWindow(SubProcessDialog):
         SubProcessDialog.show(self)
         QtCore.QTimer.singleShot(1, self.load)
 
+    def exec_(self):
+        QtCore.QTimer.singleShot(1, self.load)
+        return SubProcessDialog.exec_(self)
+
     @runs_in_loading_queue
     @ui_current_widget
     @reports_exception()
@@ -718,6 +731,9 @@ class CommitWindow(SubProcessDialog):
 
     def closeEvent(self, event):
         self._save_or_wipe_commit_data()
+        qbzr_config = get_qbzr_config()
+        qbzr_config.set_option(self._window_name + "_show_nonversioned", self.show_nonversioned_checkbox.isChecked())
+        qbzr_config.save() # do I need this or is .saveSize() enough?
         return SubProcessDialog.closeEvent(self, event)
 
     def reject(self):
